#!/usr/bin/env node
"use strict";
exports.__esModule = true;
var yarrrrgs = require("yargs");
var checkPeerDependencies_1 = require("./checkPeerDependencies");
var packageManager_1 = require("./packageManager");
var options = yarrrrgs
    .option('help', {
    alias: 'h',
    boolean: true,
    description: "Print usage information"
})
    .option('yarn', {
    boolean: true,
    description: "Force yarn package manager"
})
    .option('npm', {
    boolean: true,
    description: "Force npm package manager"
})
    .option('orderBy', {
    choices: ['depender', 'dependee'],
    "default": 'dependee',
    description: 'Order the output by depender or dependee'
})
    .option('debug', {
    boolean: true,
    "default": false,
    description: 'Print debugging information'
})
    .option('verbose', {
    boolean: true,
    "default": false,
    description: 'Prints every peer dependency, even those that are met'
})
    .option('runOnlyOnRootDependencies', {
    boolean: true,
    "default": false,
    description: 'Run tool only on package root dependencies'
})
    .option('findSolutions', {
    boolean: true,
    "default": false,
    description: 'Search for solutions and print package installation commands'
})
    .option('install', {
    boolean: true,
    "default": false,
    description: 'Install missing or incorrect peerDependencies'
})
    .check(function (argv) {
    if (argv.yarn && argv.npm) {
        throw new Error('Specify either --yarn or --npm but not both');
    }
    return true;
}).argv;
if (options.help) {
    process.exit(-2);
}
var packageManager = packageManager_1.getPackageManager(options.yarn, options.npm);
checkPeerDependencies_1.checkPeerDependencies(packageManager, options);
